( cd usr/lib ; rm -rf libgtk-x11-2.0.so.0 )
( cd usr/lib ; ln -sf libgtk-x11-2.0.so.0.1200.9 libgtk-x11-2.0.so.0 )
( cd usr/lib ; rm -rf libgdk_pixbuf-2.0.so )
( cd usr/lib ; ln -sf libgdk_pixbuf-2.0.so.0.1200.9 libgdk_pixbuf-2.0.so )
( cd usr/lib ; rm -rf libgdk_pixbuf_xlib-2.0.so )
( cd usr/lib ; ln -sf libgdk_pixbuf_xlib-2.0.so.0.1200.9 libgdk_pixbuf_xlib-2.0.so )
( cd usr/lib ; rm -rf libgtk-x11-2.0.so )
( cd usr/lib ; ln -sf libgtk-x11-2.0.so.0.1200.9 libgtk-x11-2.0.so )
( cd usr/lib ; rm -rf libgdk-x11-2.0.so )
( cd usr/lib ; ln -sf libgdk-x11-2.0.so.0.1200.9 libgdk-x11-2.0.so )
( cd usr/lib ; rm -rf libgdk_pixbuf-2.0.so.0 )
( cd usr/lib ; ln -sf libgdk_pixbuf-2.0.so.0.1200.9 libgdk_pixbuf-2.0.so.0 )
( cd usr/lib ; rm -rf libgdk_pixbuf_xlib-2.0.so.0 )
( cd usr/lib ; ln -sf libgdk_pixbuf_xlib-2.0.so.0.1200.9 libgdk_pixbuf_xlib-2.0.so.0 )
( cd usr/lib ; rm -rf libgdk-x11-2.0.so.0 )
( cd usr/lib ; ln -sf libgdk-x11-2.0.so.0.1200.9 libgdk-x11-2.0.so.0 )
